@@ -10,6 +10,7 @@ Author: Nikolay Lysenko
 import numpy as np
 
 from sinethesizer.oscillators import generate_mono_wave
+from sinethesizer.utils.misc import mix_with_original_sound
 
 
 def apply_absolute_tremolo(
@@ -36,9 +37,7 @@ def apply_absolute_tremolo(
     if not (0 < amplitude <= 1):
         raise ValueError("Amplitude for tremolo must be between 0 and 1.")
     amplitude_envelope = amplitude * np.ones(sound.shape[1])
-    volume_wave = generate_mono_wave(
-        waveform, frequency, amplitude_envelope, event.frame_rate
-    )
+    volume_wave = generate_mono_wave(waveform, frequency, amplitude_envelope, event.frame_rate)
     volume_wave += 1
     sound *= volume_wave
     return sound
@@ -71,6 +70,7 @@ def apply_relative_tremolo(
     return sound
 
 
+@mix_with_original_sound
 def apply_tremolo(
         sound: np.ndarray, event: 'sinethesizer.synth.core.Event',
         kind: str = 'absolute', *args, **kwargs
@@ -92,7 +92,5 @@ def apply_tremolo(
     elif kind == 'relative':
         sound = apply_relative_tremolo(sound, event, *args, **kwargs)
     else:
-        raise ValueError(
-            f"Kind must be either 'absolute' or 'relative', but found: {kind}"
-        )
+        raise ValueError(f"Kind must be either 'absolute' or 'relative', but found: {kind}")
     return sound
