@@ -13,10 +13,9 @@ import numpy as np
 
 from sinethesizer.effects import EFFECT_FN_TYPE, get_effects_registry
 from sinethesizer.envelopes import ENVELOPE_FN_TYPE
-from sinethesizer.synth.event_to_amplitude_factor import (
-    EVENT_TO_AMPLITUDE_FACTOR_FN_TYPE
-)
+from sinethesizer.synth.event_to_amplitude_factor import EVENT_TO_AMPLITUDE_FACTOR_FN_TYPE
 from sinethesizer.oscillators import generate_mono_wave
+from sinethesizer.utils.misc import sum_two_sounds
 
 
 class Event(NamedTuple):
@@ -33,9 +32,8 @@ class Event(NamedTuple):
     :param frequency:
         fundamental frequency of a sound to be synthesized
     :param velocity:
-        force of sound generation; it can be likened to force of piano key
-        pressing; it is a float between 0 and 1; it can affect volume and
-        frequency spectrum
+        force of sound generation; it can be likened to force of piano key pressing;
+        it is a float between 0 and 1; it can affect volume and frequency spectrum
     :param effects:
         JSON string representing list of effects that should be applied to
         resulting sound
@@ -250,8 +248,7 @@ def generate_modulated_wave(
         constant = int(not wave.amplitude_modulator.use_ring_modulation)
         modulators_as_arrays['amplitude_modulator'] += constant
     modulators_as_arrays['phase_modulator'] = introduce_quasiperiodicity(
-        modulators_as_arrays['phase_modulator'],
-        n_frames, event.frame_rate, frequency,
+        modulators_as_arrays['phase_modulator'], n_frames, event.frame_rate, frequency,
         wave.quasiperiodic_bandwidth, wave.quasiperiodic_breakpoints_frequency
     )
 
@@ -301,30 +298,6 @@ class Partial(NamedTuple):
     effects: List[EFFECT_FN_TYPE]
 
 
-def sum_two_sounds(
-        first_sound: np.ndarray, second_sound: np.ndarray
-) -> np.ndarray:
-    """
-    Sum two sounds of probably unequal durations.
-
-    :param first_sound:
-        first sound as array of shape (n_channels, n_frames)
-    :param second_sound:
-        second sound as array of shape (n_channels, n_frames)
-    :return:
-        sum of the sounds
-    """
-    first_n_frames = first_sound.shape[1]
-    second_n_frames = second_sound.shape[1]
-    n_extra_frames = abs(first_n_frames - second_n_frames)
-    padding = np.zeros((first_sound.shape[0], n_extra_frames))
-    if first_n_frames > second_n_frames:
-        second_sound = np.hstack((second_sound, padding))
-    elif first_n_frames < second_n_frames:
-        first_sound = np.hstack((first_sound, padding))
-    return first_sound + second_sound
-
-
 def generate_partial(partial: Partial, event: Event) -> np.ndarray:
     """
     Generate partial (fundamental or overtone).
